.. testbuddy-g5k documentation master file, created by
   sphinx-quickstart on Mon Jul  8 16:02:06 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to testbuddy-g5k's documentation!
=========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   add_experiment
   configuration_file
   fenicsx-tests-gsoc2024

.. toctree::
   :maxdepth: 2
   :caption: Appendix:

   Git Repository <https://salsa.debian.org/_-/testbuddy-g5k>
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
